@@ -2,7 +2,6 @@
 
 """This is the main module that contains views and the main logic"""
 
-# Libraries:
 import curses
 import time
 import getopt
@@ -10,7 +9,6 @@ import sys
 import importlib
 import logging
 
-# Modules:
 from calcure.calendars import Calendar
 from calcure.configuration import cf
 from calcure.weather import Weather
@@ -41,7 +39,7 @@ else:
     from calcure.translations.en import *
 
 
-__version__ = "2.7.6"
+__version__ = "2.8.3"
 
 
 def read_items_from_user_arguments(screen, user_tasks, user_events, task_saver_csv, event_saver_csv):
@@ -221,7 +219,7 @@ class JournalView(View):
             task_view = TaskView(self.stdscr, self.y, self.x, task, self.screen)
             task_view.render()
             if self.screen.selection_mode:
-                self.display_line(self.y, self.x, str(index + 1), Color.TODAY)
+                self.display_line(self.y, self.x, str(index + 1), Color.ACTIVE_PANE)
             self.y += 1
 
         self.y += 1
@@ -247,7 +245,7 @@ class EventView(View):
 
     @property
     def color(self):
-        """Select the color depending on the status and type"""
+        """Assign color depending on the status or calendar number if it's from .ics file"""
         if self.event.calendar_number is None:
             if self.event.status == Status.IMPORTANT:
                 return Color.IMPORTANT
@@ -391,7 +389,7 @@ class DailyView(View):
         self.index_offset = index_offset
         self.y_cell = (self.screen.y_max - 3) // 6
         self.x_cell = self.screen.x_max // 7
-        self.hidden_events_sign = cf.HIDDEN_ICON + " "*(self.x_cell-len(cf.HIDDEN_ICON))
+        self.hidden_events_sign = cf.HIDDEN_ICON + " "*(self.screen.x_max-self.x-len(cf.HIDDEN_ICON))
         self.num_events_this_day = 0
         self.is_selection_day = is_selection_day
 
@@ -405,7 +403,7 @@ class DailyView(View):
                 user_event_view = UserEventView(self.stdscr, self.y + index, self.x, event, self.screen)
                 user_event_view.render()
                 if self.screen.selection_mode and self.is_selection_day:
-                    self.display_line(self.y + index, self.x, str(index + self.index_offset + 1), Color.TODAY)
+                    self.display_line(self.y + index, self.x, str(index + self.index_offset + 1), Color.ACTIVE_PANE)
             else:
                 self.display_line(self.y + self.y_cell - 2, self.x, self.hidden_events_sign, Color.EVENTS)
             index += 1
@@ -696,7 +694,8 @@ class DailyScreenView(View):
 
         is_selection_day = True
         for _ in range(max_num_days):
-            day_string = f'{self.screen.day} {DAYS[self.week_day]} {self.icon}'
+            day_string = f"{self.screen.day} {DAYS[self.week_day]} {self.icon}"
+            day_string += " " * (max([len(day_name) for day_name in DAYS]) + 3 + len(self.icon) - len(day_string))
             self.display_line(self.y + 2 + vertical_shift, self.x, day_string, self.color)
 
             daily_view = DailyView(self.stdscr, self.y + 3 + vertical_shift, self.x, repeated_user_events,
@@ -880,13 +879,13 @@ class HelpScreenView(View):
         self.display_line(self.global_shift_y + 2, self.global_shift_x + 8,
                           TITLE_KEYS_GENERAL, Color.TITLE, cf.BOLD_TITLE, cf.UNDERLINED_TITLE)
         for index, key in enumerate(KEYS_GENERAL):
-            self.display_line(self.global_shift_y + index + 3, self.global_shift_x, key, Color.TODAY)
+            self.display_line(self.global_shift_y + index + 3, self.global_shift_x, key, Color.ACTIVE_PANE)
             self.display_line(self.global_shift_y + index + 3, self.global_shift_x + 8, KEYS_GENERAL[key], Color.TODO)
 
         self.display_line(self.global_shift_y + 4 + len(KEYS_GENERAL), self.global_shift_x + 8,
                           TITLE_KEYS_CALENDAR, Color.TITLE, cf.BOLD_TITLE, cf.UNDERLINED_TITLE)
         for index, key in enumerate(KEYS_CALENDAR):
-            self.display_line(self.global_shift_y + index + 5 + len(KEYS_GENERAL), self.global_shift_x, key, Color.TODAY)
+            self.display_line(self.global_shift_y + index + 5 + len(KEYS_GENERAL), self.global_shift_x, key, Color.ACTIVE_PANE)
             self.display_line(self.global_shift_y + index + 5 + len(KEYS_GENERAL), self.global_shift_x + 8,
                                                                             KEYS_CALENDAR[key], Color.TODO)
 
@@ -895,7 +894,7 @@ class HelpScreenView(View):
         d_y = self.global_shift_y + self.shift_y
         self.display_line(d_y, d_x + 8, TITLE_KEYS_JOURNAL, Color.TITLE, cf.BOLD_TITLE, cf.UNDERLINED_TITLE)
         for index, key in enumerate(KEYS_TODO):
-            self.display_line(d_y + index + 1, d_x, key, Color.TODAY)
+            self.display_line(d_y + index + 1, d_x, key, Color.ACTIVE_PANE)
             self.display_line(d_y + index + 1, d_x + 8, KEYS_TODO[key], Color.TODO)
 
         # Additional info:
@@ -916,6 +915,7 @@ def main(stdscr) -> None:
         weather.load_from_wttr()
     screen = Screen(stdscr, cf)
 
+    # Initialise loaders:
     event_loader_csv = EventLoaderCSV(cf)
     task_loader_csv = TaskLoaderCSV(cf)
     event_loader_ics = EventLoaderICS(cf)
@@ -923,6 +923,7 @@ def main(stdscr) -> None:
     birthday_loader = BirthdayLoader(cf)
     holiday_loader = HolidayLoader(cf)
 
+    # Load the data:
     user_events = event_loader_csv.load()
     user_tasks = task_loader_csv.load()
     user_ics_events = event_loader_ics.load()
@@ -930,6 +931,7 @@ def main(stdscr) -> None:
     holidays = holiday_loader.load()
     birthdays = birthday_loader.load()
 
+    # Initialise savers and importers:
     event_saver_csv = EventSaverCSV(user_events, cf)
     task_saver_csv = TaskSaverCSV(user_tasks, cf)
     importer = Importer(user_tasks, user_events, cf)
