@@ -99,7 +99,7 @@ class Config:
                 "color_active_pane":     "2",
                 "color_separator":       "7",
                 "color_calendar_border": "7",
-                "color_ics_calendars":   "2,3,1,7",
+                "color_ics_calendars":   "2,3,1,7,4,5,2,3,1,7",
                 "color_background":      "-1",
                 }
 
@@ -334,7 +334,7 @@ class Config:
                     self.DEFAULT_VIEW = AppState.HELP
                 elif opt in ('-v'):
                     self.DEFAULT_VIEW = AppState.EXIT
-                    print ('Calcure - version 2.8')
+                    print ('Calcure - version 2.8.2')
                 elif opt in ('-i'):
                     self.USE_PERSIAN_CALENDAR = True
         except getopt.GetoptError:
